==> jc-1.4.0.tar.gz: polyglot/ext/param/types/Subst__5fc__24ConstructorXform.h <==
// public class polyglot.ext.param.types.Subst_c$ConstructorXform

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 485fd111d7fca26b polyglot_ext_param_types_Subst__5fc__24ConstructorXform

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_param_types_Subst__5fc__24ConstructorXform_H_
#define _JC_polyglot_ext_param_types_Subst__5fc__24ConstructorXform_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_polyglot_ext_param_types_Subst__5fc$object;

// Typedefs
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$sub_refs	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$sub_refs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$sub_nonrefs	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$sub_nonrefs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$refs	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$refs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$nonrefs	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$nonrefs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$object	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$object;

typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vmethods	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vmethods;
typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtable	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtable;
typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtype	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtype;

// Constructors
extern void _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$method$_init$6b84d2d2ede79d86(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$object *, struct _jc_polyglot_ext_param_types_Subst__5fc$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$method$transform$ebefcdad8030daa7(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$method_info$transform$ebefcdad8030daa7;

// Virtual methods structure
struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vmethods {
	struct _jc_java_lang_Object$object	*(*transform$ebefcdad8030daa7)(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vmethods	polyglot_ext_param_types_Subst__5fc__24ConstructorXform;
};

// Vtype
struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtype {
	_jc_type			type;
	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$sub_refs {
	struct _jc_polyglot_ext_param_types_Subst__5fc$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$refs {
    _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$sub_refs	polyglot_ext_param_types_Subst__5fc__24ConstructorXform;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$sub_nonrefs	polyglot_ext_param_types_Subst__5fc__24ConstructorXform;
};

// Object instance structure
struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$object {
	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtype	*vtype;
	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtype _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_param_types_Subst__5fc__24ConstructorXform, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$class_object;

#endif	/* _JC_polyglot_ext_param_types_Subst__5fc__24ConstructorXform_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/param/types/Subst__5fc__24ConstructorXform.h <==
// public class polyglot.ext.param.types.Subst_c$ConstructorXform

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 485fd111d7fca26b polyglot_ext_param_types_Subst__5fc__24ConstructorXform

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_param_types_Subst__5fc__24ConstructorXform_H_
#define _JC_polyglot_ext_param_types_Subst__5fc__24ConstructorXform_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_polyglot_ext_param_types_Subst__5fc$object;

// Typedefs
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$sub_refs	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$sub_refs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$sub_nonrefs	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$sub_nonrefs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$refs	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$refs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$nonrefs	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$nonrefs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$object	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$object;

typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vmethods	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vmethods;
typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtable	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtable;
typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtype	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtype;

// Constructors
extern void _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$method$_init$6b84d2d2ede79d86(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$object *, struct _jc_polyglot_ext_param_types_Subst__5fc$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$method$transform$ebefcdad8030daa7(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$method_info$transform$ebefcdad8030daa7;

// Virtual methods structure
struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vmethods {
	struct _jc_java_lang_Object$object	*(*transform$ebefcdad8030daa7)(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vmethods	polyglot_ext_param_types_Subst__5fc__24ConstructorXform;
};

// Vtype
struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtype {
	_jc_type			type;
	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$sub_refs {
	struct _jc_polyglot_ext_param_types_Subst__5fc$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$refs {
    _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$sub_refs	polyglot_ext_param_types_Subst__5fc__24ConstructorXform;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$sub_nonrefs	polyglot_ext_param_types_Subst__5fc__24ConstructorXform;
};

// Object instance structure
struct _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$object {
	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtype	*vtype;
	_jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$vtype _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_param_types_Subst__5fc__24ConstructorXform, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_param_types_Subst__5fc__24ConstructorXform$class_object;

#endif	/* _JC_polyglot_ext_param_types_Subst__5fc__24ConstructorXform_H_ */
